@@ -10,8 +10,8 @@ our $JOBJ = JSON::MaybeXS->new();
 our $YOBJ;
 our $_last_out = "";
 
-our @EXPORT = qw/jsonize jsonise J parsej pretty_json ugly_json/;
-our $VERSION = "0.200";
+our @EXPORT = qw/jsonize jsonise J yamlize yamlise Y parsej pretty_json ugly_json/;
+our $VERSION = "0.201";
 
 sub jobj { $JOBJ }
 
@@ -21,12 +21,16 @@ sub jsonize (;$) {
     return $_last_out;
   }
   if (ref $inp) { # encode perl object
-    return $_last_out = jobj()->encode($inp);
+    my ($a,$b,$c,$subr,@rest) = caller(1);
+    return $_last_out = ($subr && $subr =~ /Y|yamli[sz]e$/) ? Dump($inp) : jobj()->encode($inp);
   }
-  else { # scalar: decode if looks like json, or slurp if filename
+  else { # scalar: decode if looks like json or yaml, or slurp if filename
     if (looks_like_json($inp)) {
       return $_last_out = jobj()->decode($inp);
     }
+    elsif (looks_like_yaml($inp)) {
+      return $_last_out = Load($inp);
+    }
     else { # try as file
       local $/;
       my ($j,$f);
@@ -49,6 +53,9 @@ sub jsonize (;$) {
           try { # might be YAML
             $_last_out = Load($j);
           } catch {
+            if (looks_like_yaml($j)) {
+              die "YAML decode barfed.\nYAML err: $_";
+            }
             die "Both JSON and YAML decodes barfed.\nJSON err: $jerr\nYAML err: $_";
           };
         };
@@ -60,6 +67,9 @@ sub jsonize (;$) {
 
 sub jsonise (;$) { jsonize($_[0]) }
 sub J (;$) { jsonize($_[0]) }
+sub yamlize (;$) { jsonize($_[0]) }
+sub yamlise (;$) { jsonize($_[0]) }
+sub Y (;$) { jsonize($_[0]) }
 
 
 sub parsej () {
@@ -74,6 +84,13 @@ sub looks_like_json {
   return $ck =~ /^\s*[[{]/;
 }
 
+sub looks_like_yaml {
+  my $ck = $_[0];
+  my @l = $ck =~ /^(?:---|\s+-\s\w+|\s*\w+\s?:\s+\S+)$/gm;
+  return @l && ($l[0] eq '---' || @l > 2 );
+}
+
+
 =head1 NAME
 
  JSON::ize - Use JSON easily in one-liners - now with YAMLific action
@@ -84,6 +101,10 @@ sub looks_like_json {
 
  $ perl -MJSON::ize -le '$j=jsonize("my.yaml"); print $j->{thingy};'
 
+ # or yamlize, if you prefer
+
+ $ perl -MJOSN::ize -le '$j=yamlize("my.yaml"); print $j->{thingy};'
+
  # plus yamls all the way down...
 
  # if you have PerlIO::gzip, this works
@@ -102,13 +123,37 @@ sub looks_like_json {
 
  $ perl -MJSON::ize -e 'ugly_json; print J(J("indented.json"));' # strip whsp
 
+ # JSON to YAML
+
+ $ perl -MJSON::ize -e 'print yamlize jsonize "my.json"'
+
+ $ perl -MJSON::ize -e 'print Y J "my.json"' 
+
+ # and back 
+
+ $ perl -MJSON::ize -e 'print jsonize yamlize "my.yaml"'
+
+ $ perl -MJSON::ize -e 'print J Y "my.yaml"' 
 
 =head1 DESCRIPTION
 
-JSON::ize exports a function, C<jsonize()>, that will do what you mean with the argument. 
-If argument is a filename, it will try to read the file and decode it as JSON or YAML.
-If argument is a string that looks like JSON, it will try to encode it.
-If argument is a Perl hashref or arrayref, it will try to encode it as JSON.
+JSON::ize exports a function, C<jsonize()>, and some synonyms (see below), that will do what you mean with the argument. 
+
+If argument is a filename, it will try to read the file and decode it from JSON or YAML.
+
+If argument is a string that looks like JSON or YAML, it will try to encode it:
+
+=over
+
+=item *
+
+If argument is a Perl hashref or arrayref, and you called C<jsonize()>, it will try to encode it as JSON.
+
+=item *
+
+If argument is a Perl hashref or arrayref, and you called C<yamlize()>, it will try to encode it as YAML.
+
+=back
 
 The underlying L<JSON> object is
 
@@ -120,10 +165,15 @@ The underlying L<JSON> object is
 
 =item jsonize($j), jsonise($j), J($j)
 
-Try to DWYM.
+Try to DWYM. In particular, encode to JSON.
 If called without argument, return the last value returned. Use this to retrieve
 after L</parsej>.
 
+=item yamlize($j), yamlise($j), Y($j)
+
+Try to DWYM. In particular, encode to YAML.
+If called without argument, return the last value returned.
+
 =item parsej
 
 Parse a piped-in stream of json. Use jsonize() (without arg) to retrieve the object.
